@@ -18,19 +18,17 @@
  ***************************************************************************/
 
 #include "kmagselrect.h"
-#include "kmagselrect.moc"
 
-#include <QtGui/QApplication>
-#include <QtGui/QCursor>
-#include <QtGui/QPixmap>
-#include <QtGui/QBitmap>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QLabel>
-#include <QtGui/QDesktopWidget>
+// Qt
+#include <QApplication>
+#include <QBitmap>
+#include <QCursor>
+#include <QDesktopWidget>
+#include <QMouseEvent>
+// KF5
+#include <KLocalizedString>
 
-#include <klocale.h>
-
-static uchar line_bits[] = {0x2d, 0x96, 0x4b, 0xa5, 0xd2, 0x69, 0xb4, 0x5a};
+static const uchar line_bits[] = {0x2d, 0x96, 0x4b, 0xa5, 0xd2, 0x69, 0xb4, 0x5a};
 
 static QColor titleColor = QColor (0,0,128);
 static QColor titleBtnColor = QColor (255,255,0);
@@ -155,8 +153,8 @@ void KMagSelRect::show()
 {
   if (selectionwindow == 0) {
     selectionwindow = new KMagSelWin (selWindowParent);
-    selectionwindow->setObjectName( QLatin1String("selectionwindow" ));
-    connect (selectionwindow, SIGNAL (resized()), this, SLOT (selWinResized()));
+    selectionwindow->setObjectName( QStringLiteral("selectionwindow" ));
+    connect (selectionwindow, &KMagSelWin::resized, this, &KMagSelRect::selWinResized);
 
     update();
     selectionwindow->show();
@@ -201,7 +199,7 @@ void setPaletteColor(QWidget* w, QPalette::ColorRole r, const QColor& c)
   w->setPalette(p);
 }
 
-KMagSelWin::KMagSelWin ( QWidget * parent, Qt::WFlags ) :
+KMagSelWin::KMagSelWin ( QWidget * parent ) :
     QWidget(parent) //Qt::WStyle_Customize | Qt::WStyle_NoBorder | Qt::WStyle_StaysOnTop | Qt::WType_TopLevel | Qt::WX11BypassWM)
 {
   setWindowFlags( Qt::CustomizeWindowHint | Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint | Qt::X11BypassWindowManagerHint);
@@ -211,39 +209,39 @@ KMagSelWin::KMagSelWin ( QWidget * parent, Qt::WFlags ) :
   setPalette(p);
 
   titleBar = new KMagSelWinCorner (this);
-  titleBar->setObjectName( QLatin1String("titlebar" ));
+  titleBar->setObjectName( QStringLiteral("titlebar" ));
   setPaletteColor(titleBar, QPalette::Background, getTitleColor());
   setPaletteColor(titleBar, QPalette::Foreground, getTextColor());
   titleBar->setText(i18n("Selection Window")+QLatin1String( " - " )+i18n("KMagnifier"));
-  connect (titleBar, SIGNAL (startResizing()), this, SLOT (startResizing()));
+  connect (titleBar, &KMagSelWinCorner::startResizing, this, &KMagSelWin::startResizing);
   connect (titleBar, SIGNAL (resized(QPoint)), this, SLOT (titleMoved(QPoint)));
 
   topLeftCorner = new KMagSelWinCorner (this);
-  topLeftCorner->setObjectName( QLatin1String("topleft" ));
+  topLeftCorner->setObjectName( QStringLiteral("topleft" ));
   topLeftCorner->setCursor (Qt::SizeFDiagCursor);
   setPaletteColor(topLeftCorner, QPalette::Background, getTitleBtnColor());
-  connect (topLeftCorner, SIGNAL (startResizing()), this, SLOT (startResizing()));
+  connect (topLeftCorner, &KMagSelWinCorner::startResizing, this, &KMagSelWin::startResizing);
   connect (topLeftCorner, SIGNAL (resized(QPoint)), this, SLOT (topLeftResized(QPoint)));
 
   topRightCorner = new KMagSelWinCorner (this);
-  topRightCorner->setObjectName( QLatin1String("topright" ));
+  topRightCorner->setObjectName( QStringLiteral("topright" ));
   topRightCorner->setCursor (Qt::SizeBDiagCursor);
   setPaletteColor(topRightCorner, QPalette::Background, getTitleBtnColor ());
-  connect (topRightCorner, SIGNAL (startResizing()), this, SLOT (startResizing()));
+  connect (topRightCorner, &KMagSelWinCorner::startResizing, this, &KMagSelWin::startResizing);
   connect (topRightCorner, SIGNAL (resized(QPoint)), this, SLOT (topRightResized(QPoint)));
 
   bottomLeftCorner = new KMagSelWinCorner (this);
-  bottomLeftCorner->setObjectName( QLatin1String("bottomleft" ));
+  bottomLeftCorner->setObjectName( QStringLiteral("bottomleft" ));
   bottomLeftCorner->setCursor (Qt::SizeBDiagCursor);
   setPaletteColor(bottomLeftCorner, QPalette::Background, getTitleBtnColor());
-  connect (bottomLeftCorner, SIGNAL (startResizing()), this, SLOT (startResizing()));
+  connect (bottomLeftCorner, &KMagSelWinCorner::startResizing, this, &KMagSelWin::startResizing);
   connect (bottomLeftCorner, SIGNAL (resized(QPoint)), this, SLOT (bottomLeftResized(QPoint)));
 
   bottomRightCorner = new KMagSelWinCorner (this);
-  bottomRightCorner->setObjectName( QLatin1String("bottomright" ));
+  bottomRightCorner->setObjectName( QStringLiteral("bottomright" ));
   bottomRightCorner->setCursor (Qt::SizeFDiagCursor);
   setPaletteColor(bottomRightCorner, QPalette::Background, getTitleBtnColor ());
-  connect (bottomRightCorner, SIGNAL (startResizing()), this, SLOT (startResizing()));
+  connect (bottomRightCorner, &KMagSelWinCorner::startResizing, this, &KMagSelWin::startResizing);
   connect (bottomRightCorner, SIGNAL (resized(QPoint)), this, SLOT (bottomRightResized(QPoint)));
 }
 
@@ -349,8 +347,8 @@ void KMagSelWin::bottomRightResized (const QPoint &offset)
 //   KMagSelWinCorner
 //--------------------------------------------------------------------------
 
-KMagSelWinCorner::KMagSelWinCorner ( QWidget * parent, Qt::WFlags f ) :
-    QLabel (parent, f)
+KMagSelWinCorner::KMagSelWinCorner ( QWidget * parent ) :
+    QLabel (parent)
 {
   setFrameStyle (QFrame::WinPanel | QFrame::Raised);
   setLineWidth (1);
