@@ -24,47 +24,34 @@
 
 // application specific includes
 #include "kmagzoomview.h"
-#include "kmagzoomview.moc"
 #include "colorsim.h"
 
 // include files for Qt
-#include <QtGui/QBitmap>
-#include <QtGui/QCursor>
-#include <QtCore/qglobal.h>
-#include <QtGui/QPainter>
-#include <QtGui/QWidget>
-#include <QtGui/QScrollBar>
-#include <QtGui/QPixmap>
-#include <QtGui/QFocusEvent>
-#include <QtGui/QHideEvent>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QShowEvent>
-#include <QtGui/QResizeEvent>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QDesktopWidget>
-#include <QtDBus/QDBusConnection>
+#include <QApplication>
+#include <QBitmap>
+#include <QDesktopWidget>
+#include <QScrollBar>
+#include <QScreen>
+
+// include files for KF5
+#include <KLocalizedString>
 
-// include files for KDE
-#include <kapplication.h>
-#include <kcursor.h>
-#include <kdebug.h>
-#include <klocale.h>
 #ifdef QAccessibilityClient_FOUND
 #include <qaccessibilityclient/accessibleobject.h>
 #endif
 
 // include bitmaps for cursors
-static uchar left_ptr_bits[] = {
+static const uchar left_ptr_bits[] = {
    0x00, 0x00, 0x08, 0x00, 0x18, 0x00, 0x38, 0x00, 0x78, 0x00, 0xf8, 0x00,
    0xf8, 0x01, 0xf8, 0x03, 0xf8, 0x07, 0xf8, 0x00, 0xd8, 0x00, 0x88, 0x01,
    0x80, 0x01, 0x00, 0x03, 0x00, 0x03, 0x00, 0x00};
 
-static uchar left_ptrmsk_bits[] = {
+static const uchar left_ptrmsk_bits[] = {
    0x0c, 0x00, 0x1c, 0x00, 0x3c, 0x00, 0x7c, 0x00, 0xfc, 0x00, 0xfc, 0x01,
    0xfc, 0x03, 0xfc, 0x07, 0xfc, 0x0f, 0xfc, 0x0f, 0xfc, 0x01, 0xdc, 0x03,
    0xcc, 0x03, 0x80, 0x07, 0x80, 0x07, 0x00, 0x03};
 
-static uchar phand_bits[] = {
+static const uchar phand_bits[] = {
   0x00, 0x00, 0x00, 0x00,  0xfe, 0x01, 0x00, 0x00,  0x01, 0x02, 0x00, 0x00,
   0x7e, 0x04, 0x00, 0x00,  0x08, 0x08, 0x00, 0x00,  0x70, 0x08, 0x00, 0x00,
   0x08, 0x08, 0x00, 0x00,  0x70, 0x14, 0x00, 0x00,  0x08, 0x22, 0x00, 0x00,
@@ -76,7 +63,7 @@ static uchar phand_bits[] = {
   0x00, 0x00, 0x00, 0x00,  0x00, 0x00, 0x00, 0x00,  0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00,  0x00, 0x00, 0x00, 0x00,  0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00,  0x00, 0x00, 0x00, 0x00 };
-    static uchar phandm_bits[] = {
+static const uchar phandm_bits[] = {
   0xfe, 0x01, 0x00, 0x00,  0xff, 0x03, 0x00, 0x00,  0xff, 0x07, 0x00, 0x00,
   0xff, 0x0f, 0x00, 0x00,  0xfe, 0x1f, 0x00, 0x00,  0xf8, 0x1f, 0x00, 0x00,
   0xfc, 0x1f, 0x00, 0x00,  0xf8, 0x3f, 0x00, 0x00,  0xfc, 0x7f, 0x00, 0x00,
@@ -123,12 +110,12 @@ KMagZoomView::KMagZoomView(QWidget *parent, const char *name)
   setRefreshRate(10);
 
   // connect it to grabFrame()
-  connect(&m_grabTimer, SIGNAL(timeout()), SLOT(grabFrame()));
+  connect(&m_grabTimer, &QTimer::timeout, this, &KMagZoomView::grabFrame);
   // start the grabTimer
   m_grabTimer.start(static_cast<int>(1000.0/m_fps));
 
   // connect it to updateMouseView()
-  connect(&m_mouseViewTimer, SIGNAL(timeout()), SLOT(updateMouseView()));
+  connect(&m_mouseViewTimer, &QTimer::timeout, this, &KMagZoomView::updateMouseView);
   // start the grabTimer @ 25 frames per second!
   m_mouseViewTimer.start(40);
 
@@ -136,7 +123,7 @@ KMagZoomView::KMagZoomView(QWidget *parent, const char *name)
  selected region. The contents will be magnified according to the zoom level that is set."));
 
   // different ways to show the cursor.
-  m_showMouseTypes << QLatin1String( "Hidden" ) << QLatin1String( "Box" ) << QLatin1String( "Arrow" ) << QLatin1String( "Actual" );
+  m_showMouseTypes << QStringLiteral( "Hidden" ) << QStringLiteral( "Box" ) << QStringLiteral( "Arrow" ) << QStringLiteral( "Actual" );
 
   if(m_fitToWindow)
     fitToWindow();
@@ -407,10 +394,9 @@ void KMagZoomView::paintMouseCursor(QPaintDevice *dev, const QPoint &mousePos)
     {
       // 3. Actual cursor
       // Get the current cursor type
-      QWidget *dummy  = KApplication::topLevelAt(QCursor::pos());
+      QWidget *dummy  = QApplication::topLevelAt(QCursor::pos());
       if(!dummy)
         break;
-      kDebug() << ">" << dummy->objectName() << ":" << dummy->cursor().shape() << "-";
       switch(this->cursor().shape())  {
 			  case Qt::ArrowCursor :
          {
@@ -970,8 +956,9 @@ void KMagZoomView::grabFrame()
   QRect selRect = m_selRect.normalized();
 
   // grab screenshot from the screen and put it in the pixmap
-  m_coloredPixmap = QPixmap::grabWindow(QApplication::desktop()->winId(), selRect.x(), selRect.y(),
-                                        selRect.width(), selRect.height());
+  QScreen *screen = qApp->primaryScreen(); // ## How to select the right screen?
+  m_coloredPixmap = screen->grabWindow(QApplication::desktop()->winId(), selRect.x(), selRect.y(),
+                                      selRect.width(), selRect.height());
 
   // colorize the grabbed pixmap
   if (m_colormode != 0)
